"""Test ferda context processors."""

from unittest.mock import patch

from django.test import TestCase, override_settings
from django.urls import reverse

from ferda.plugins import PluginConfig


class TestFerdaModules(TestCase):
    """Test ferda_modules."""

    @override_settings(ROOT_URLCONF="ferda.tests.urls", DJANGO_FIDO_TWO_STEP_AUTH=False)
    @patch("ferda.context_processors.CONFIG", {})
    def test_empty(self):
        response = self.client.get(reverse("ferda:login"))
        self.assertEqual(response.context["ferda_plugins"], {})

    @override_settings(ROOT_URLCONF="ferda.tests.urls", DJANGO_FIDO_TWO_STEP_AUTH=False)
    @patch(
        "ferda.context_processors.CONFIG", {"registry": PluginConfig(name="Registry", url="/", access=lambda x: True)}
    )
    def test_access_true(self):
        response = self.client.get(reverse("ferda:login"))
        self.assertEqual(
            response.context["ferda_plugins"],
            {
                "registry": {
                    "name": "Registry",
                    "url": "/",
                    "icon": None,
                }
            },
        )

    @override_settings(ROOT_URLCONF="ferda.tests.urls", DJANGO_FIDO_TWO_STEP_AUTH=False)
    @patch(
        "ferda.context_processors.CONFIG", {"registry": PluginConfig(name="Registry", url="/", access=lambda x: False)}
    )
    def test_access_false(self):
        response = self.client.get(reverse("ferda:login"))
        self.assertEqual(response.context["ferda_plugins"], {})
