"""Ferda view mixins."""

from abc import ABC, abstractproperty

from django.core.exceptions import ImproperlyConfigured

from ferda.plugins import CONFIG


class PluginMixin(ABC):
    """Ferda plugin mixin.

    Attributes:
        plugin (str): name of registered plugin

    Each view of Ferda's plugin that want's to be shown in plugins menu
    should inherit this mixin or its descendant.
    """

    @abstractproperty
    def plugin(self) -> str:
        """Return plugin handle."""

    def get_context_data(self, **kwargs) -> dict:
        """Return context with ferda modules config."""
        if self.plugin not in CONFIG:
            raise ImproperlyConfigured(f"Ferda plugin {self.plugin} is not properly registred")

        context = super().get_context_data(**kwargs)  # type: ignore
        context["active_plugin"] = self.plugin
        context["active_plugin_name"] = CONFIG[self.plugin].name
        return context


class RegistryPluginMixin(PluginMixin):
    """Registry plugin mixin.

    Each registry view should inherit from this mixin.
    """

    plugin = "registry"
